@@ -13,6 +13,6 @@ def open(q, ex):
 
     from IPython.display import IFrame
 
-    open(2, 10, IFrame) открывает q2.10
+    open(2, 10) открывает q2.10
     """
-    return IFrame(f'./q{q}-{ex}.pdf', width=600, height=300)
+    return IFrame(f'./1.pdf', width=600, height=300)
